using System.Drawing;
using Infragistics.Win;
using Infragistics.Win.UltraWinProgressBar;

namespace TestProgressBar
{
    internal class FormBasedPartValueDrawFilter : IUIElementDrawFilter
    {
        private readonly ITaskProgress m_taskProgress;
        private static readonly SolidBrush m_selectedBrush = new SolidBrush(Color.Blue);
        private static readonly SolidBrush m_rejectedBrush = new SolidBrush(Color.Red);
        private static readonly SolidBrush m_sucessededBrush = new SolidBrush(Color.Green);

        public FormBasedPartValueDrawFilter(ITaskProgress taskProgress)
        {
            m_taskProgress = taskProgress;
        }

        #region Implementation of IUIElementDrawFilter

        public DrawPhase GetPhasesToFilter(ref UIElementDrawParams drawParams)
        {
            // If the element being drawn is a ProgressFillTextUIElement 
            // we're interested in drawing its borders only.
            if (drawParams.Element is ProgressFillTextUIElement)
                return DrawPhase.BeforeDrawBackColor ;
            
            return DrawPhase.None;
        }

        public bool DrawElement(DrawPhase drawPhase, ref UIElementDrawParams drawParams)
        {


            // This will only be called for the BeforeDrawBackColor phase of a 
            // ProgressFillTextUIElement based on the flags returned from 
            // GetPhasesToFilter. 

            // Draw a border along the top edge of the element.
            Rectangle elementRect = drawParams.Element.Rect;




            int rejectedWidth = 0, sucessededWidth = 0;
            if (m_taskProgress.Selected != 0)
            {
                rejectedWidth = (int)(elementRect.Width * (m_taskProgress.Rejected / (double)m_taskProgress.Selected));
                sucessededWidth = (int)(elementRect.Width * (m_taskProgress.Sucesseded / (double)m_taskProgress.Selected));
            }

            Rectangle rejecetedRect = new Rectangle(elementRect.Location.X,
                                                    elementRect.Location.Y,
                                                    rejectedWidth,
                                                    elementRect.Height);

            Rectangle sucessededRect = new Rectangle(elementRect.Location.X + rejectedWidth, 
                                                     elementRect.Location.Y, 
                                                     sucessededWidth, 
                                                     elementRect.Height);
            Rectangle selectedRect = new Rectangle(elementRect.Location.X + rejectedWidth + sucessededWidth, 
                                                   elementRect.Location.Y,
                                                   elementRect.Width - rejectedWidth - sucessededWidth, 
                                                   elementRect.Height);



            drawParams.Graphics.FillRectangle(m_selectedBrush, selectedRect);
            drawParams.Graphics.FillRectangle(m_rejectedBrush, rejecetedRect);
            drawParams.Graphics.FillRectangle(m_sucessededBrush, sucessededRect);

            // Return true to prevent the element from drawing 
            // its borders normally.
            return true;

        }

        #endregion
    }
}