using System.Diagnostics;
using System.Drawing;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win.UltraWinProgressBar;

namespace TestProgressBar
{
    internal class GridBasedPartValueDrawFilter : IUIElementDrawFilter
    {
        private static readonly SolidBrush m_selectedBrush = new SolidBrush(Color.Blue);
        private static readonly SolidBrush m_rejectedBrush = new SolidBrush(Color.Red);
        private static readonly SolidBrush m_sucessededBrush = new SolidBrush(Color.Green);

        #region Implementation of IUIElementDrawFilter

        public DrawPhase GetPhasesToFilter(ref UIElementDrawParams drawParams)
        {
            // If the element being drawn is a ProgressFillTextUIElement 
            // we're interested in drawing its borders only.
            if (drawParams.Element is ProgressFillTextUIElement)
                return DrawPhase.BeforeDrawBackColor;

            return DrawPhase.None;
        }

        public bool DrawElement(DrawPhase drawPhase, ref UIElementDrawParams drawParams)
        {


            // This will only be called for the BeforeDrawBackColor phase of a 
            // ProgressFillTextUIElement based on the flags returned from 
            // GetPhasesToFilter. 

            // Draw a border along the top edge of the element.
            Rectangle elementRect = drawParams.Element.Rect;


            ITaskProgress localTaskProgress =null;
            UltraGridCell cell = drawParams.Element.GetContext(typeof(UltraGridCell)) as UltraGridCell;
            if (cell != null)
            {
                if (cell.Value is ITaskProgress)
                {
                    localTaskProgress = (ITaskProgress)cell.Value;
                }
            }
            
            if(localTaskProgress == null)
            {
                localTaskProgress = new TaskProgress { Selected = 0, Rejected = 0, Sucesseded = 0 };
            }

            int rejectedWidth = 0, sucessededWidth = 0;
            if (localTaskProgress.Selected != 0)
            {
                rejectedWidth = (int)(elementRect.Width * (localTaskProgress.Rejected / (double)localTaskProgress.Selected));
                sucessededWidth = (int)(elementRect.Width * (localTaskProgress.Sucesseded / (double)localTaskProgress.Selected));
            }

            Rectangle rejecetedRect = new Rectangle(elementRect.Location.X,
                                                    elementRect.Location.Y,
                                                    rejectedWidth,
                                                    elementRect.Height);

            Rectangle sucessededRect = new Rectangle(elementRect.Location.X + rejectedWidth,
                                                     elementRect.Location.Y,
                                                     sucessededWidth,
                                                     elementRect.Height);

            Rectangle selectedRect = new Rectangle(elementRect.Location.X + rejectedWidth + sucessededWidth,
                                                   elementRect.Location.Y,
                                                   elementRect.Width - rejectedWidth - sucessededWidth,
                                                   elementRect.Height);

            Debug.WriteLine(drawParams.Element);
            Debug.WriteLine(selectedRect);
            Debug.WriteLine(sucessededRect);
            Debug.WriteLine(rejecetedRect);


            drawParams.Graphics.FillRectangle(m_selectedBrush, selectedRect);
            drawParams.Graphics.FillRectangle(m_rejectedBrush, rejecetedRect);
            drawParams.Graphics.FillRectangle(m_sucessededBrush, sucessededRect);

            // Return true to prevent the element from drawing 
            // its borders normally.
            return true;

        }

        #endregion
    }
}